@@ -52,7 +52,7 @@ require AutoLoader;
 	KRB5_NT_UNKNOWN
 	KRB5_TGS_NAME
 );
-$VERSION = '1.3';
+$VERSION = '1.5';
 
 sub KRB5_TGS_NAME() { return "krbtgt"; }
 
@@ -175,6 +175,21 @@ cache.
 
 Returns a Authen::Krb5::Keytab object representing the specified keytab name.
 
+=item kt_default_name()
+
+Returns a sting containing the default keytab name.
+
+=item kt_default()
+
+Returns an Authen::Krb5::Keytab object representing the default keytab.
+
+=item kt_read_service_key(name, principal[, kvno, enctype])
+
+Searches the keytab specified by I<name> (the default keytab if
+I<name> is undef) for a key matching I<principal> (and optionally
+I<kvno> and I<enctype>) and returns the key in the form of an
+Authen::Krb5::Keyblock object.
+
 =item get_in_tkt_with_password(client,server,password,cc)
 
 Attempt to get an initial ticket for the client.  'client' is a principal
@@ -275,6 +290,8 @@ Returns a Authen::Krb5::Rcache object using the replay cache name 'name.'
 
 =head2 CLASSES & METHODS
 
+=over 4
+
 =item Authen::Krb5::Principal
 
 Kerberos 5 princpal object.
@@ -321,6 +338,30 @@ Destroys the credentials cache and releases all resources it used.
 
 =back
 
+=item Authen::Krb5::KeyBlock
+
+Kerberos 5 keyblock object.
+
+=over 4
+
+=item o enctype()
+
+Returns the encryption type ID.
+
+=item o enctype_string()
+
+Returns a text description of the encryption type.
+
+=item o length()
+
+Returns the length of the session key.
+
+=item o contents()
+
+Returns the actual contents of the keyblock (the session key).
+
+=back
+
 =item Authen::Krb5::AuthContext
 
 Kerberos 5 auth_context object.
@@ -347,6 +388,10 @@ AuthContext object.
 Sets the replay cache for auth_context.  'rc' is a Authen::Krb5::Rcache object
 generated by get_server_rcache.
 
+=item o getkey()
+
+Retrieves the session key as an Authen::Krb5::KeyBlock object.
+
 =back
 
 =item Authen::Krb5::Ticket
@@ -378,6 +423,95 @@ The client principal contained in the ticket.
 
 =back
 
+=item Authen::Krb5::Keyblock
+
+Object representation of the krb5_keyblock structure.
+
+=over 4
+
+=item o enctype
+
+The integral enctype of the key.
+
+=item o length
+
+Length of the key.
+
+=item o contents
+
+Contents of the key itself, as a string.
+
+=back
+
+=item Authen::Krb5::Keytab
+
+=over 4
+
+=item o add_entry(entry)
+
+Adds I<entry> to the keytab.
+
+=item o remove_entry(entry)
+
+Removes I<entry> from the keytab.
+
+=item o get_name()
+
+Returns the name of the keytab.
+
+=item o get_entry(principal[, kvno, enctype])
+
+Returns an Authen::Krb5::KeytabEntry object representing an entry in
+the keytab matching I<principal> and optionally I<kvno> and
+I<enctype>.
+
+=item o start_seq_get()
+
+Returns a cursor that can be passed to I<next_entry()> to read in turn
+every key in the keytab.
+
+=item o next_entry(cursor)
+
+Returns the next entry in the keytab as an Authen::Krb5::KeytabEntry
+object.
+
+=item o end_seq_get(cursor)
+
+Perform cleanup opreations after I<next_entry()> and invalidates
+I<cursor>.
+
+=back
+
+=item Authen::Krb5::KeytabEntry
+
+=over 4
+
+=item o new(principal, kvno, keyblock)
+
+Create a new Authen::Krb5::KeytabEntry object from an
+Authen::Krb5::Principal object, a key version number, and an
+Authen::Krb5::Keyblock object.
+
+=item o principal
+
+An Authen::Krb5::Principal object representing the principal contained
+in the entry.
+
+=item o timestamp
+
+The timestamp of the entry.
+
+=item o kvno
+
+The key version number of the key contained in the entry.
+
+=item o key
+
+An Authen::Krb5::Keyblock object representing a copy of the keyblock
+contained in the entry.
+
+=back
+
 =head1 AUTHOR
 
 Jeff Horwitz (jeff@laserlink.net)
